
//	Metamaxim ModelScope
//	Copyright 2004 Metamaxim Ltd

package Gold;

import com.metamaxim.modelscope.callbacks.*;


public class Rules {

	public static boolean checkNotification (Instance offer, Instance prospect, int expectedMatchesCount) {
	// Determines whether a Notification of this Offer to this Prospect (Dealer) is allowed

		Instance offerMaker = offer.getInstance("Offer Maker");
		int i;

		// Cannot notify offer to self
		if (offerMaker.equals(prospect)) return false;

		// Cannot notify offer to a prospect who has already been notified
		// If this is a pre-update check the expected matches is 0 (i.e., check no matching Notification exists).
		// If a post-update check the expected matches is 1 (i.e., check that the Notification is unique)
		Instance[] myNotifications = offer.selectByRef("Notification", "Offer");
		int j = 0;
		for (i = 0; i < myNotifications.length; i++)
			if (myNotifications[i].getInstance("Prospect").equals(prospect)  &&
				myNotifications[i].getState("Notification").equals("open")) j++;
		if (j > expectedMatchesCount) return false;

		// Check whether there is a Liaison that allows or disallows notifying this prospect
		boolean found = false;
		boolean result = false;
		Instance[] myLiaisons = offerMaker.selectByRef("Liaison", "Offer Maker");
		for (i = 0; i < myLiaisons.length; i++)
			if (myLiaisons[i].getInstance("Prospect").equals(prospect) &&
				myLiaisons[i].getState("Liaison").equals("active")) {
				found = true;
				result = myLiaisons[i].getBoolean("Notification Allowed");
			}
		if (found) return result;

		// Otherwise use the default rule for notification
		if (offerMaker.getState("Size").equals("little") &&
			prospect.getState("Size").equals("big")) return false;
		else return true;
	}

}


